<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//sv_SE

$LANG=array();


$LANG['backup'][0]="Spara SQL"; 
$LANG['backup'][1]="Spara XML"; 
$LANG['backup'][11]="Storlek"; 
$LANG['backup'][13]="Visa/Ladda ned"; 
$LANG['backup'][16]="Ersätt innehållet i databasen med backupfilen:"; 
$LANG['backup'][17]="Är du säker på att du vill radera filen"; 
$LANG['backup'][18]="Säkerhetskopiera databasen"; 
$LANG['backup'][19]="nu"; 
$LANG['backup'][21]="Filen existerar redan"; 
$LANG['backup'][22]="Kunde inte hitta datat"; 
$LANG['backup'][23]="Fel i MySQL med början i"; 
$LANG['backup'][24]="Automatisk omdirigering, om inte klicka"; 

$LANG['bookmark'][1]="bokmärke"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Du har ännu inte skapat några bokmärken."; 
$LANG['bookmark'][4]="Nytt bokmärke"; 
$LANG['bookmark'][5]="Publika bokmärken"; 
$LANG['bookmark'][6]="Tillämpa som standard"; 

$LANG['buttons'][0]="Sök"; 
$LANG['buttons'][2]="Skicka"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Installera"; 
$LANG['buttons'][5]="Avinstallera"; 
$LANG['buttons'][6]="Radera"; 
$LANG['buttons'][7]="Uppdatera"; 
$LANG['buttons'][8]="Skapa"; 
$LANG['buttons'][9]="Anslut"; 
$LANG['buttons'][10]="Koppla från"; 
$LANG['buttons'][11]="Nästa"; 
$LANG['buttons'][12]="Föregående"; 
$LANG['buttons'][13]="Tillbaka"; 
$LANG['buttons'][14]="Uppdatera"; 
$LANG['buttons'][15]="Schemalägg"; 
$LANG['buttons'][16]="Tom"; 
$LANG['buttons'][17]="Invertera valet"; 
$LANG['buttons'][18]="Markera alla"; 
$LANG['buttons'][19]="Avmarkera alla"; 
$LANG['buttons'][20]="Flytta"; 
$LANG['buttons'][21]="Återställ"; 
$LANG['buttons'][22]="Rensa bort"; 
$LANG['buttons'][23]="Visa"; 
$LANG['buttons'][24]="Upp"; 
$LANG['buttons'][25]="Ned"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Exportera"; 
$LANG['buttons'][32]="Slut"; 
$LANG['buttons'][33]="Start"; 
$LANG['buttons'][34]="Avbryt"; 
$LANG['buttons'][37]="Importera"; 
$LANG['buttons'][38]="Lås upp"; 
$LANG['buttons'][39]="Byt ut"; 
$LANG['buttons'][40]="Visa alla"; 
$LANG['buttons'][41]="Aktivera"; 
$LANG['buttons'][42]="Inaktivera"; 
$LANG['buttons'][43]="Bläddra"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Före"; 
$LANG['buttons'][47]="Efter"; 
$LANG['buttons'][48]="Överför"; 
$LANG['buttons'][49]="Behåll"; 
$LANG['buttons'][50]="Testa"; 
$LANG['buttons'][51]="Spara"; 
$LANG['buttons'][52]="Hämta"; 
$LANG['buttons'][53]="Rensa"; 
$LANG['buttons'][55]="Först"; 
$LANG['buttons'][56]="Sist"; 
$LANG['buttons'][57]="Exekvera"; 
$LANG['buttons'][58]="Uppdatera"; 
$LANG['buttons'][59]="Åtskilja"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="S"; 
$LANG['calendarD'][1]="M"; 
$LANG['calendarD'][2]="T"; 
$LANG['calendarD'][3]="O"; 
$LANG['calendarD'][4]="T"; 
$LANG['calendarD'][5]="L"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Söndag"; 
$LANG['calendarDay'][1]="Måndag"; 
$LANG['calendarDay'][2]="Tisdag"; 
$LANG['calendarDay'][3]="Onsdag"; 
$LANG['calendarDay'][4]="Torsdag"; 
$LANG['calendarDay'][5]="Fredag"; 
$LANG['calendarDay'][6]="Lördag"; 

$LANG['calendarM'][0]="januari"; 
$LANG['calendarM'][1]="februari"; 
$LANG['calendarM'][2]="mars"; 
$LANG['calendarM'][3]="april"; 
$LANG['calendarM'][4]="maj"; 
$LANG['calendarM'][5]="juni"; 
$LANG['calendarM'][6]="juli"; 
$LANG['calendarM'][7]="augusti"; 
$LANG['calendarM'][8]="september"; 
$LANG['calendarM'][9]="oktober"; 
$LANG['calendarM'][10]="november"; 
$LANG['calendarM'][11]="december"; 

$LANG['cartridges'][0]="Patron/Toner"; 
$LANG['cartridges'][7]="Ingen patron/toner funnen"; 
$LANG['cartridges'][9]="Ingen patron/toner"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Patron/toner typ"; 
$LANG['cartridges'][13]="Ny"; 
$LANG['cartridges'][14]="Använd"; 
$LANG['cartridges'][15]="Gammal"; 
$LANG['cartridges'][16]="Patroner/toners"; 
$LANG['cartridges'][20]="Ny"; 
$LANG['cartridges'][21]="Använda"; 
$LANG['cartridges'][22]="Gammal"; 
$LANG['cartridges'][24]="Påfyllnadsdatum"; 
$LANG['cartridges'][27]="På"; 
$LANG['cartridges'][29]="Slut"; 
$LANG['cartridges'][32]="Kompatibla skrivarmodeller"; 
$LANG['cartridges'][33]="Använda patroner/toners"; 
$LANG['cartridges'][34]="Inga lediga patroner/toners"; 
$LANG['cartridges'][35]="Gamla patroner/toners"; 
$LANG['cartridges'][37]="Band"; 
$LANG['cartridges'][39]="Utskriftsräknare"; 
$LANG['cartridges'][40]="Genomsnittlig tid i lager"; 
$LANG['cartridges'][41]="Medelvärde för användningstid"; 
$LANG['cartridges'][42]="Medelvärde för antal skrivna sidor"; 

$LANG['central'][2]="Senaste"; 
$LANG['central'][4]="Inga ärenden"; 
$LANG['central'][5]="Hem"; 
$LANG['central'][6]="Logga ut"; 
$LANG['central'][7]="Hjälp"; 
$LANG['central'][8]="transaktionerna"; 
$LANG['central'][9]="Dina pågående ärenden"; 
$LANG['central'][10]="Nya ärenden"; 
$LANG['central'][12]="Personlig vy"; 
$LANG['central'][13]="Global vy"; 
$LANG['central'][14]="Gruppvy"; 
$LANG['central'][18]="Biljetter att stänga"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Nej"; 
$LANG['choice'][1]="Ja"; 

$LANG['common'][0]="Utan namn"; 
$LANG['common'][1]="Objekt"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Webb"; 
$LANG['common'][5]="Tillverkare"; 
$LANG['common'][6]="Mallnamn"; 
$LANG['common'][7]="Välj en mall"; 
$LANG['common'][8]="Hantera mallar"; 
$LANG['common'][9]="Ny mall"; 
$LANG['common'][10]="Tekniskt ansvarig"; 
$LANG['common'][11]="Begränsad vy"; 
$LANG['common'][12]="Inställning"; 
$LANG['common'][13]="Mall"; 
$LANG['common'][14]="Mallar"; 
$LANG['common'][15]="Plats"; 
$LANG['common'][16]="Namn"; 
$LANG['common'][17]="Typ"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Serienummer"; 
$LANG['common'][20]="Inventarienummer"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Modell"; 
$LANG['common'][23]="Åtgärd lyckades"; 
$LANG['common'][24]="Inget valt element eller felaktigt definierad operation"; 
$LANG['common'][25]="Kommentarer"; 
$LANG['common'][26]="Senaste uppdatering"; 
$LANG['common'][27]="Datum"; 
$LANG['common'][28]="Raderad"; 
$LANG['common'][29]="Tillägg"; 
$LANG['common'][30]="Ny post"; 
$LANG['common'][31]="Tom mall"; 
$LANG['common'][32]="Egenskaper"; 
$LANG['common'][33]="Total"; 
$LANG['common'][34]="Användare"; 
$LANG['common'][35]="Grupp"; 
$LANG['common'][36]="Kategori"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="kopiera elementet lika många gånger som det finns anslutningar"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="E-post Alarm"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Förnamn"; 
$LANG['common'][44]="Standardvärde"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="VCard"; 
$LANG['common'][47]="Förlopp"; 
$LANG['common'][48]="Efternamn"; 
$LANG['common'][49]="Inget"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="Fullständigt namn"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Lista"; 
$LANG['common'][54]="Objektet hittades inte"; 
$LANG['common'][55]="Vill du verkligen ta bort...?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Titel"; 
$LANG['common'][58]="Maxvärde"; 
$LANG['common'][59]="Global"; 
$LANG['common'][60]="Aktiv"; 
$LANG['common'][61]="Okänt fel"; 
$LANG['common'][62]="Annan"; 
$LANG['common'][63]="Fel"; 
$LANG['common'][64]="Chef"; 
$LANG['common'][65]="Interface"; 
$LANG['common'][66]="Alla"; 
$LANG['common'][67]="Andra"; 
$LANG['common'][68]="Liggande"; 
$LANG['common'][69]="Stående"; 
$LANG['common'][70]="Objektet har lagts till"; 
$LANG['common'][71]="Objektet har uppdaterats"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Objektet är återställt"; 
$LANG['common'][75]="Du har ingen behörighet till att göra detta objekt rekursivt i denna enhet"; 
$LANG['common'][76]="Publik"; 
$LANG['common'][77]="Privat"; 
$LANG['common'][78]="Gör publik"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="Under laddning..."; 
$LANG['common'][81]="Visa inte raderade objekt"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Ändring av flagga förbjuden. Länkade objekt funna."; 
$LANG['common'][85]="Ändra synlighet i dotterenheter"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="Nytt kort"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Ej installerad"; 
$LANG['common'][90]="Objekt"; 
$LANG['common'][91]="Attribut kan ej ändras då det ärvs från högre nivå."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Volym"; 
$LANG['computers'][1]="Andel ledigt"; 
$LANG['computers'][2]="Totalt ledigt"; 
$LANG['computers'][3]="Total storlek"; 
$LANG['computers'][4]="Filsystem"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Lägg till en volym"; 
$LANG['computers'][8]="Volymer"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Infogad"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Ingen ansluten bildskräm"; 
$LANG['computers'][38]="Ingen ansluten skrivare"; 
$LANG['computers'][39]="Skrivare"; 
$LANG['computers'][40]="Bildskärm(ar)"; 
$LANG['computers'][46]="Kringutrustning"; 
$LANG['computers'][47]="Ingen ansluten kringutrustning"; 
$LANG['computers'][48]="Platsuppdatering. Associerade objekt har flyttats till samma plats."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Användar eller gruppupdatering. Associerade objekt har uppdaterats med gemensamma data."; 
$LANG['computers'][51]="Uppdateringskälla"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Servicepacket"; 
$LANG['computers'][54]="Ingen ansluten telefonienhet"; 
$LANG['computers'][55]="Telefonienhet(er)"; 
$LANG['computers'][56]="Statusen uppdaterad. De anslutna objekten har uppdaterats med denna status."; 

$LANG['connect'][0]="Direkta anslutningar"; 
$LANG['connect'][1]="Ej ansluten"; 
$LANG['connect'][15]="Automatisk uppdatering av följande objekt"; 
$LANG['connect'][16]="Varning. Nedanstående objekt matchar inte varandra"; 

$LANG['consumables'][0]="Förbrukningsvara"; 
$LANG['consumables'][1]="I lager"; 
$LANG['consumables'][2]="Referens"; 
$LANG['consumables'][7]="Ingen förbrukningsvara funnen"; 
$LANG['consumables'][9]="Ingen förbrukningsvara"; 
$LANG['consumables'][12]="Typ av förbrukningsvara"; 
$LANG['consumables'][13]="Ny"; 
$LANG['consumables'][15]="Använd"; 
$LANG['consumables'][16]="Förbrukningsvaror"; 
$LANG['consumables'][20]="Ny"; 
$LANG['consumables'][22]="Använd"; 
$LANG['consumables'][23]="Status"; 
$LANG['consumables'][26]="Använd datum"; 
$LANG['consumables'][32]="Ge"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Lagerplats"; 
$LANG['consumables'][37]="Tillbaks till lager"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Kontrakt utgick den"; 
$LANG['contract'][1]="Kontrakt utgår"; 

$LANG['crontask'][0]="Schemalagda aktiviteter"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Skicka larm om patron/toner"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="Så snart som möjligt"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Ny kringutrustning"; 
$LANG['devices'][1]="Hårddisk"; 
$LANG['devices'][2]="Grafikkort"; 
$LANG['devices'][3]="Nätverkskort"; 
$LANG['devices'][4]="Processor"; 
$LANG['devices'][5]="Moderkort"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Ljudkort"; 
$LANG['devices'][19]="Diskar"; 
$LANG['devices'][20]="Kontrollenheter"; 
$LANG['devices'][21]="Andra komponenter"; 
$LANG['devices'][22]="Chassilådor"; 
$LANG['devices'][23]="Nätaggregat"; 
$LANG['devices'][24]="som standard"; 
$LANG['devices'][25]="Lägg till en kringutrustning"; 
$LANG['devices'][26]="Ta bort en kringutrustning"; 

$LANG['device_case'][0]="Storlek"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Skrivbar"; 
$LANG['device_drive'][1]="Hastighet"; 

$LANG['device_hdd'][0]="RPM"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Kapacitet"; 

$LANG['device_iface'][0]="Trafik"; 
$LANG['device_iface'][2]="MAC adress"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Effekt"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekvens"; 
$LANG['device_ram'][2]="Storlek"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Fil"; 
$LANG['document'][3]="Rubrik"; 
$LANG['document'][4]="MIME-typ"; 
$LANG['document'][7]="Dokumenttyper"; 
$LANG['document'][9]="Filändelse"; 
$LANG['document'][10]="Ikon"; 
$LANG['document'][11]="Auktoriserad nedladdning"; 
$LANG['document'][15]="Ladda ned"; 
$LANG['document'][16]="Nytt dokument"; 
$LANG['document'][18]="Dokument"; 
$LANG['document'][19]="Associerade objekt"; 
$LANG['document'][21]="Associerade dokument"; 
$LANG['document'][22]="Nuvarande fil"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Radering av fil lyckades"; 
$LANG['document'][25]="Radering av fil misslyckades"; 
$LANG['document'][26]="Filen är godkänd. Uppladdning lyckades"; 
$LANG['document'][27]="Potentiell uppladdningsattack, eller filen för stor. Flytt av temporärfil misslyckades."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Skapande av bibliotek misslyckades"; 
$LANG['document'][30]="Kontrollera dina rättigheter"; 
$LANG['document'][31]="Bibliotek för dokument existerar ej"; 
$LANG['document'][32]="Ogiltig filtyp"; 
$LANG['document'][33]="Webblänk"; 
$LANG['document'][34]="Skapa bibliotek"; 
$LANG['document'][35]="Biblioteket för uppladdning existerar ej"; 
$LANG['document'][36]="Använd uppladdad FTP fil"; 
$LANG['document'][37]="Ingen fil tillgänglig"; 
$LANG['document'][38]="Ingen fil funnen"; 
$LANG['document'][39]="Förflyttning av dokument utförd"; 
$LANG['document'][40]="Förflyttning av fil misslyckades"; 
$LANG['document'][41]="Kopiering av dokument lyckades"; 
$LANG['document'][42]="Lagt upp av"; 
$LANG['document'][43]="Okänd fil"; 
$LANG['document'][44]="Ogiltigt filnamn"; 
$LANG['document'][45]="Otillåten filåtkomst"; 
$LANG['document'][46]="Kunde inte skicka filen. (Troligen för stor)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="File is altered (bad checksum)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Enhet"; 
$LANG['entity'][2]="Rot-enhet"; 
$LANG['entity'][3]="Koppla till en enhet"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Automatisk användartilldelning"; 
$LANG['entity'][7]="trädstruktur"; 
$LANG['entity'][8]="Per enhet"; 
$LANG['entity'][9]="Dotterenheter"; 
$LANG['entity'][10]="Välj önskad enhet"; 
$LANG['entity'][11]="för att se enheten och underenheter"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Tjänst"; 
$LANG['event'][3]="Nivå"; 
$LANG['event'][4]="Meddelande"; 
$LANG['event'][18]="Fält"; 
$LANG['event'][19]="Uppdatering"; 
$LANG['event'][20]="Ingen historik funnen"; 

$LANG['financial'][1]="Avtal"; 
$LANG['financial'][2]="Vid liv"; 
$LANG['financial'][3]="Finansiell information"; 
$LANG['financial'][4]="Nummer"; 
$LANG['financial'][5]="Kostnad"; 
$LANG['financial'][6]="Avtalstyp"; 
$LANG['financial'][8]="Period"; 
$LANG['financial'][9]="år"; 
$LANG['financial'][10]="Meddelande"; 
$LANG['financial'][11]="Fakturaperiod"; 
$LANG['financial'][13]="Kontonummer"; 
$LANG['financial'][14]="Inköpsdatum"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Garantiinformation"; 
$LANG['financial'][18]="Ordernummer"; 
$LANG['financial'][19]="Leveranstyp"; 
$LANG['financial'][20]="Immobiliseringsnummer"; 
$LANG['financial'][21]="Värde"; 
$LANG['financial'][22]="Amorteringstyp"; 
$LANG['financial'][23]="Avbetalningsperiod"; 
$LANG['financial'][24]="Ny kontakt"; 
$LANG['financial'][25]="Ny leverantör..."; 
$LANG['financial'][26]="Leverantör"; 
$LANG['financial'][30]="Telefaxnummer"; 
$LANG['financial'][33]="Ny kontakt"; 
$LANG['financial'][36]="Nytt avtal"; 
$LANG['financial'][42]="Kommersiell"; 
$LANG['financial'][43]="Tekniskt ansvarig"; 
$LANG['financial'][44]="Adress"; 
$LANG['financial'][45]="Webbsajt"; 
$LANG['financial'][46]="Associerade kontakter"; 
$LANG['financial'][47]="Rak"; 
$LANG['financial'][48]="Minskande"; 
$LANG['financial'][50]="Lån"; 
$LANG['financial'][51]="Hyra"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Försäkring"; 
$LANG['financial'][54]="Hårdvarusupport"; 
$LANG['financial'][55]="MjukvaruSupport"; 
$LANG['financial'][56]="Försedd Tjänst"; 
$LANG['financial'][57]="månad(er)"; 
$LANG['financial'][59]="Interventionstimmar"; 
$LANG['financial'][60]="Måndag-Fredag"; 
$LANG['financial'][61]="Lördag"; 
$LANG['financial'][62]="Söndag & helgdag"; 
$LANG['financial'][65]="Associerade leverantörer"; 
$LANG['financial'][66]="Associerade avtal"; 
$LANG['financial'][68]="Aktivera finansiell information"; 
$LANG['financial'][69]="Avtalsperiod"; 
$LANG['financial'][76]="Startdatum"; 
$LANG['financial'][77]="Amorteringskoefficient"; 
$LANG['financial'][78]="Värde vid garantitidens slut"; 
$LANG['financial'][79]="Tredjepartstyp"; 
$LANG['financial'][80]="Garanti upphör den"; 
$LANG['financial'][81]="Kontots netto värde"; 
$LANG['financial'][82]="Fakturanummer"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="För denna typ av element är den finansiella informationen bara en modell för de element du bör lägga till."; 
$LANG['financial'][85]="Begärt objekt kunde ej hittas"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Budget"; 
$LANG['financial'][88]="Giltig till:"; 
$LANG['financial'][89]="TCO (Värde + spårnings kostnad)"; 
$LANG['financial'][90]="Månadsvis TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Avtal utgångna de senaste 30 dagarna"; 
$LANG['financial'][94]="Avtal som går ut inom 7 dagar"; 
$LANG['financial'][95]="Avtal som går ut inom 30 dagar"; 
$LANG['financial'][96]="Avtal där uppsägningstiden utgår inom 7 dagar"; 
$LANG['financial'][97]="Avtal där uppsägningstiden inträffar inom 30 dagar"; 
$LANG['financial'][98]="Avslut"; 
$LANG['financial'][99]="Utgångsdatum + Uppsägning"; 
$LANG['financial'][100]="Postnummer"; 
$LANG['financial'][101]="Ort"; 
$LANG['financial'][102]="Stat"; 
$LANG['financial'][103]="Land"; 
$LANG['financial'][104]="Associerade objekt"; 
$LANG['financial'][105]="Tyst överenskommelse"; 
$LANG['financial'][106]="Express"; 
$LANG['financial'][107]="Förnyelse"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="timme/timmar"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Väldigt hög"; 
$LANG['help'][4]="Hög"; 
$LANG['help'][5]="Medium"; 
$LANG['help'][6]="Låg"; 
$LANG['help'][7]="Väldigt låg"; 
$LANG['help'][8]="Informera mig angående uppföljningar"; 
$LANG['help'][11]="Min e-post adress"; 
$LANG['help'][14]="Skicka meddelande"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Ditt ärende har emottagits och kommer behandlas så fort som möjligt."; 
$LANG['help'][19]="Tack för du använder vårt ärendehanteringssystem."; 
$LANG['help'][22]="Sök efter din dators identitet"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Hårdvarutyp"; 
$LANG['help'][25]="Dator"; 
$LANG['help'][26]="Nätverksenhet"; 
$LANG['help'][27]="Skrivare"; 
$LANG['help'][28]="Bildskärm"; 
$LANG['help'][29]="Kringutrustning"; 
$LANG['help'][30]="Allmänt"; 
$LANG['help'][31]="mjukvara"; 
$LANG['help'][35]="Telefonienheter"; 
$LANG['help'][40]="Ange ärenderubrik"; 
$LANG['help'][41]="Ange kategori i ärendet"; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="Installation eller uppdatering av GLPI"; 
$LANG['install'][1]="Välj 'Installera' för en helt ny installation av GLPI."; 
$LANG['install'][2]="Välj uppdatering för att uppgradera från tidigare version av GLPI"; 
$LANG['install'][3]="Installation"; 
$LANG['install'][4]="Uppdatering"; 
$LANG['install'][5]="Kontrollerar kompabiliteten av miljön för användning med GLPI"; 
$LANG['install'][6]="Kontroll avslutad"; 
$LANG['install'][7]="Resultat"; 
$LANG['install'][8]="Kontroll av PHP tolk"; 
$LANG['install'][9]="PHP5 behöver installeras. Du kan ladda ned det från denna plats:"; 
$LANG['install'][10]="GLPI är inte kompatibel med optionen zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP tolken är åtminstone version 5.x - Bra!"; 
$LANG['install'][12]="Kontroll av sessioner"; 
$LANG['install'][13]="PHP tolken är inte kompilerad för att stödja sessionshantering"; 
$LANG['install'][14]="PHP tolken stödjer sessionshantering"; 
$LANG['install'][15]="Kontrollera att stöd för sessionshantering är aktiverad i din php.ini"; 
$LANG['install'][16]="Kontrollerar skrivrättigheter för backup filer"; 
$LANG['install'][17]="Filen kan ej skapas"; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="Filen skapades men kunde ej raderas"; 
$LANG['install'][20]="En fil och en mapp skapades och raderades - Bra!"; 
$LANG['install'][21]="Kontrollerar skrivrättigheter för dokument"; 
$LANG['install'][22]="En fil kunde skapas - Perfekt!"; 
$LANG['install'][23]="Kontrollerar skrivrättigheter för inställningsfiler"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Fortsätt?"; 
$LANG['install'][26]="Fortsätt"; 
$LANG['install'][27]="Försök igen"; 
$LANG['install'][28]="Inställningar för anslutning till databas"; 
$LANG['install'][29]="Parametrar för anslutning till databas"; 
$LANG['install'][30]="MySQL värd"; 
$LANG['install'][31]="MySQL användare"; 
$LANG['install'][32]="MySQL lösenord"; 
$LANG['install'][34]="Kontroll av anslutning till databasen"; 
$LANG['install'][35]="Anslutning till databasen misslyckades"; 
$LANG['install'][36]="Server svarade"; 
$LANG['install'][37]="Server- och/eller användarfält är tomt"; 
$LANG['install'][38]="Välj databas:"; 
$LANG['install'][39]="Ny databas, eller använd en existerande:"; 
$LANG['install'][40]="Välj databas att uppdatera"; 
$LANG['install'][41]="Kan ej använda databasen:"; 
$LANG['install'][43]="Databasen är initialiserad"; 
$LANG['install'][47]="Sparning av inställningsfil för anslutning till databasen misslyckades"; 
$LANG['install'][48]="Skapande av databasen misslyckades"; 
$LANG['install'][49]="Du har ej valt en databas"; 
$LANG['install'][50]="Kontrollera skrivrättigheterna för sessionsfilerna"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Testar skrivrättighet till loggfiler"; 
$LANG['install'][55]="Installationen avslutad"; 
$LANG['install'][57]="Standard konton och lösenord:"; 
$LANG['install'][58]="glpi/glpi för administratörens konto"; 
$LANG['install'][59]="tech/tech för den tekniska ansvariges konto"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Starta GLPI"; 
$LANG['install'][65]="Kontroll av MAGIC_QUOTES_SYBASE tillägg"; 
$LANG['install'][66]="GLPI fungerar ej med MAGIC_QOUTES_SYBASE tillägget. Var vänlig avaktivera detta och försök igen"; 
$LANG['install'][67]="MAGIC_QUOTES_SYBASE tillägg ej aktiverat"; 
$LANG['install'][68]="Testar autostart för sessionen"; 
$LANG['install'][69]="session.auto_start är aktiverad. Mer information finns i filen .htaccess i GLPIs rootmapp."; 
$LANG['install'][70]="Skapandet av inställningsfil för anslutning till databasen misslyckades. Kontrollera skriv och läsrättigheter."; 
$LANG['install'][71]="Kontroll av MYSQL tillägg"; 
$LANG['install'][72]="PHP tolken måste komplieras med tillägget MYSQL"; 
$LANG['install'][73]="Funktionen MYSQL_QUERY() funnen"; 
$LANG['install'][74]="Kontroll om SESSION_USE_TRANS_SID användes"; 
$LANG['install'][75]="Du måste avaktivera SESSION_USE_TRANS_ID i din php.ini"; 
$LANG['install'][76]="OK - sessionerna fungerar (inga problem med trans_id) - Perfekt!"; 
$LANG['install'][77]="Steg"; 
$LANG['install'][81]="Start av installation"; 
$LANG['install'][82]="Databasen skapades"; 
$LANG['install'][85]="Funktion funnen!"; 
$LANG['install'][86]="Kontroll av minnesallokering"; 
$LANG['install'][87]="Allokerat minne:"; 
$LANG['install'][88]="Ett minimum av 64MB är vanligtvis nödvändigt för GLPI"; 
$LANG['install'][89]="Perfekt"; 
$LANG['install'][90]="Prova att öka MEMORY_LIMIT i din php.ini"; 
$LANG['install'][91]="Allokerat minne > 64MB"; 
$LANG['install'][92]="Licens"; 
$LANG['install'][93]="Jag har läst och ACCEPTERAT vilkoren i licensen ovan."; 
$LANG['install'][94]="Jag har läst och EJ ACCEPTERAT vilkoren i licensen ovan."; 
$LANG['install'][95]="Obegränsat minne"; 
$LANG['install'][96]="Obegränsat minne"; 
$LANG['install'][97]="Testar rättigheterna för mappen:"; 
$LANG['install'][99]="Testar skrivrättighet till cachefiler"; 
$LANG['install'][100]="Mappen kunde inte skapas."; 
$LANG['install'][101]="Mappen skapades men kunde inte tas bort"; 
$LANG['install'][102]="Testar json-funktioner"; 
$LANG['install'][103]="GLPI fungerar inte utan funktionerna json_encode och json_decode"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="av"; 
$LANG['job'][4]="Beställare"; 
$LANG['job'][5]="Delegerat till"; 
$LANG['job'][6]="Handläggare"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Beskrivning av ärendet"; 
$LANG['job'][12]="Inga uppföljningar registrerade för detta ärende"; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="E-post uppföljningar"; 
$LANG['job'][20]="Total tidsåtgång"; 
$LANG['job'][21]="Timmar"; 
$LANG['job'][22]="Minuter"; 
$LANG['job'][29]="Ny uppföljning"; 
$LANG['job'][30]="Lägg till ny uppgift"; 
$LANG['job'][31]="Tidsåtgång"; 
$LANG['job'][32]="Ingen"; 
$LANG['job'][33]="Beskrivning saknas"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Planering"; 
$LANG['job'][37]="Summering"; 
$LANG['job'][38]="Ärende"; 
$LANG['job'][39]="Uppdatera uppföljning"; 
$LANG['job'][40]="Kostnad (tid)"; 
$LANG['job'][41]="Kostnad (fast)"; 
$LANG['job'][42]="Kostnad (material)"; 
$LANG['job'][43]="Totalkostnad"; 
$LANG['job'][44]="Ärendekälla"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Godkännande av lösning"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Status"; 
$LANG['joblist'][1]="Endast mina"; 
$LANG['joblist'][2]="Prioritet"; 
$LANG['joblist'][3]="Egna och gruppens"; 
$LANG['joblist'][4]="Delegerad till"; 
$LANG['joblist'][6]="Beskrivning"; 
$LANG['joblist'][7]="Nytt ärende för detta objekt"; 
$LANG['joblist'][8]="Inga ärenden funna"; 
$LANG['joblist'][9]="Ny"; 
$LANG['joblist'][10]="Stängd (löst)"; 
$LANG['joblist'][11]="Öppnat"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="Inga pågående ärenden"; 
$LANG['joblist'][17]="Stängd (olöst)"; 
$LANG['joblist'][18]="Pågående  (delegerad)"; 
$LANG['joblist'][19]="Pågående (planerad)"; 
$LANG['joblist'][21]="Pågående"; 
$LANG['joblist'][26]="Väntande"; 
$LANG['joblist'][27]="E-post adress för uppföljning"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Godkänd lösning"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Välj kategori för denna artikel"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Editera artikel"; 
$LANG['knowbase'][9]="Radera artikel"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Rot"; 
$LANG['knowbase'][13]="Kategorinamn"; 
$LANG['knowbase'][14]="Ämne"; 
$LANG['knowbase'][15]="Innehåll"; 
$LANG['knowbase'][24]="Vanliga frågor och svar (FAQ)"; 
$LANG['knowbase'][26]="Vyer"; 
$LANG['knowbase'][27]="På"; 
$LANG['knowbase'][29]="De senaste bidragen"; 
$LANG['knowbase'][30]="Vanligaste frågorna"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Synkronera redan importerade användare"; 
$LANG['ldap'][2]="Importera nya användare"; 
$LANG['ldap'][3]="Inga användare att importeras"; 
$LANG['ldap'][4]="Alternativ för LDAP katalogen"; 
$LANG['ldap'][5]="Vänligen välj vilken LDAP katalog ni önskar importera användare från"; 
$LANG['ldap'][6]="Kan ej ansluta till LDAP-katalogen"; 
$LANG['ldap'][7]="Ingen LDAP-katalog har angetts i GLPI"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Testa anslutning till LDAP-katalog"; 
$LANG['ldap'][12]="Synkronisering"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="i GLPI"; 
$LANG['ldap'][15]="Synkronisera"; 
$LANG['ldap'][16]="Förkonfiguration"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Replikera"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Primär server"; 
$LANG['ldap'][22]="Replikator"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Import av nya grupper"; 
$LANG['ldap'][25]="Inga grupper att importera"; 
$LANG['ldap'][30]="Hur LDAP alias ska hanteras"; 
$LANG['ldap'][31]="Aldrig återhänvisad (standard)"; 
$LANG['ldap'][32]="Alltid återhänvisad"; 
$LANG['ldap'][33]="Återhänvisad under sökning (ej under en lokalisering)"; 
$LANG['ldap'][34]="Återhänvisad under lokalisering(ej under en sökning)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Avancerad"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Länk eller filnamn"; 
$LANG['links'][4]="Associerade hårdvarutyper"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Ingen länk definerad"; 
$LANG['links'][9]="Filinnehåll"; 

$LANG['log'][1]="system"; 
$LANG['log'][16]="planering"; 
$LANG['log'][18]="komponenter"; 
$LANG['log'][20]="nytt objekt"; 
$LANG['log'][21]="uppdatera objekt"; 
$LANG['log'][22]="radera objekt"; 
$LANG['log'][23]="återställ objekt"; 
$LANG['log'][24]="Rensa bort objekt"; 
$LANG['log'][26]="koppla från objekt"; 
$LANG['log'][27]="objekts anslutning"; 
$LANG['log'][28]="ändring av komponenter"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="associera typ"; 
$LANG['log'][31]="radera typ"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="ta bort länken till objektet"; 
$LANG['log'][34]="ny länk till leverantör"; 
$LANG['log'][35]="radera länk till leverantör"; 
$LANG['log'][40]="IP anslutning"; 
$LANG['log'][41]="anslutningen misslyckades"; 
$LANG['log'][42]="Reservation"; 
$LANG['log'][44]="Rubrik"; 
$LANG['log'][45]="Lyckades"; 
$LANG['log'][46]="Misslyckades"; 
$LANG['log'][48]="lägg till användare till grupp"; 
$LANG['log'][49]="radera användare i grupp"; 
$LANG['log'][55]="Anslutning"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="lägg till anv. till enhet"; 
$LANG['log'][62]="radera användaren fullständigt"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="regel"; 
$LANG['log'][66]="Säkerhet"; 
$LANG['log'][67]="ändring av anteckningar"; 
$LANG['log'][70]="nätverksport sparad"; 
$LANG['log'][71]="flera nätverksportar sparade"; 
$LANG['log'][73]="nätverksport raderad"; 
$LANG['log'][74]="flera nätverksportar raderade"; 
$LANG['log'][75]="nätverksport flyttad"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="lägger till version"; 
$LANG['log'][83]="ändring av version"; 
$LANG['log'][84]="versions radering"; 
$LANG['log'][85]="lägger till licens"; 
$LANG['log'][86]="ändring av licens"; 
$LANG['log'][87]="Licensers radering"; 
$LANG['log'][88]="lägger till toner"; 
$LANG['log'][89]="lägger till förbrukning"; 
$LANG['log'][90]="uteslutning av en kassett"; 
$LANG['log'][91]="uteslutning av förbrukningsmaterial"; 
$LANG['log'][92]="återställning av kassett"; 
$LANG['log'][93]="återställning av förbrukningsmaterial"; 
$LANG['log'][94]="uppdatering av kassett"; 
$LANG['log'][95]="Installation av kassett"; 
$LANG['log'][96]="avinstallation av kassett"; 
$LANG['log'][97]="förbrukningsvara slut för användaren"; 
$LANG['log'][98]="lägger till objekt"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Senaste inloggning"; 
$LANG['login'][1]="Logga in igen"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Anslutning nekad"; 
$LANG['login'][6]="Konto"; 
$LANG['login'][7]="Lösenord"; 
$LANG['login'][8]="Konto eller lösenord saknas"; 
$LANG['login'][9]="Ej autentiserad ännu"; 
$LANG['login'][10]="Autenticering"; 
$LANG['login'][11]="Användaren är ej auktoriserad att ansluta till GLPI"; 
$LANG['login'][12]="Felaktig användare eller lösenord"; 
$LANG['login'][13]="Lösenordsfältet är tomt"; 
$LANG['login'][14]="okänd användaridentitet"; 
$LANG['login'][15]="Ingen, eller flera icke-unika identiteter hittades"; 
$LANG['login'][16]="Misslyckad autentisering mot LDAP"; 
$LANG['login'][18]="GLPIs interna databas"; 
$LANG['login'][20]="Du har inte behörighet till programmet, eftersom ditt konto har avaktiverats eller flyttats"; 
$LANG['login'][21]="Testa anslutning till IMAP/POP-server"; 
$LANG['login'][22]="Testet lyckades"; 
$LANG['login'][23]="Testet misslyckades"; 
$LANG['login'][24]="Senaste inloggningsdatum"; 
$LANG['login'][25]="Du har inte rätt att ansluta"; 
$LANG['login'][26]="Du måste aktivera JavaScript i din webbläsare"; 
$LANG['login'][27]="Cookies måste tillåtas för den här applikationen"; 
$LANG['login'][30]="Ändring av autentisieringsmetod"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Inloggning mot GLPIs databas"; 
$LANG['login'][33]="Inloggning mot IMAP/POP-server"; 

$LANG['mailgate'][0]="E-postmottagare"; 
$LANG['mailgate'][2]="Hämta e-postärenden nu"; 
$LANG['mailgate'][3]="Antal tillgängliga och hämtade meddelanden"; 
$LANG['mailgate'][4]="mbstring extension not found. Warning with charsets used."; 
$LANG['mailgate'][5]="Ogiltig bifogad fil"; 
$LANG['mailgate'][6]="Bifogad fil är för stor"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Beskrivning av ärendet"; 
$LANG['mailing'][10]="Ny ärendeuppföljning"; 
$LANG['mailing'][12]="Delegera ärende till"; 
$LANG['mailing'][14]="Uppdatera ärendets kategori"; 
$LANG['mailing'][15]="Uppdatera ärendets prioritet"; 
$LANG['mailing'][17]="Uppdatera ärendets objekt"; 
$LANG['mailing'][18]="Uppdatera ärendets skapare"; 
$LANG['mailing'][19]="Ny reservation"; 
$LANG['mailing'][20]="Uppdatera ärendets grupp"; 
$LANG['mailing'][21]="Förändring av ärendekälla"; 
$LANG['mailing'][23]="Reservation modification"; 
$LANG['mailing'][26]="Bifogade dokument:"; 
$LANG['mailing'][27]="Uppdatera ärendets status"; 
$LANG['mailing'][29]="Reservation avbokad"; 
$LANG['mailing'][30]="Ärendeuppdatering"; 
$LANG['mailing'][31]="Detta är ett testmeddelande för att kontrollera e-post transmissionen"; 
$LANG['mailing'][32]="E-post test"; 
$LANG['mailing'][33]="Larm för patroner/toners"; 
$LANG['mailing'][35]="Larmnivå nådd för denna typ av förbrukningsvara:"; 
$LANG['mailing'][36]="Larm för förbrukningsvaror"; 
$LANG['mailing'][37]="Contract entered in notice time:"; 
$LANG['mailing'][39]="Larm för avtal"; 
$LANG['mailing'][40]="Objektet anlände vid garantitidens utgång:"; 
$LANG['mailing'][41]="Larm för finansiell information"; 
$LANG['mailing'][42]="Förändring av timkostnad"; 
$LANG['mailing'][43]="Förändring av fasta kostnader"; 
$LANG['mailing'][44]="Förändring av materialkostnader"; 
$LANG['mailing'][45]="Byt ärendetitel"; 
$LANG['mailing'][46]="Ändra ärendebeskrivning"; 
$LANG['mailing'][47]="Fel vid sändning av meddelande"; 
$LANG['mailing'][48]="Change in opening date"; 
$LANG['mailing'][49]="Change in closing date"; 
$LANG['mailing'][50]="Ändra ärendemottagare"; 
$LANG['mailing'][51]="Utgången licens :"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Kategorin är inte definierad"; 
$LANG['mailing'][101]="E-postuppföljning har aktiverats"; 
$LANG['mailing'][102]="E-postuppföljning har deaktiverats"; 
$LANG['mailing'][104]="Åtgärdstid för uppföljning"; 
$LANG['mailing'][105]="Ej delegerat"; 
$LANG['mailing'][107]="Inget"; 
$LANG['mailing'][109]="Ingen grupp"; 
$LANG['mailing'][110]="Ogiltig e-postadress"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Lägg till ny översättning"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Datorer"; 
$LANG['Menu'][1]="Nätverksenheter"; 
$LANG['Menu'][2]="Skrivare"; 
$LANG['Menu'][3]="Bildskärmar"; 
$LANG['Menu'][4]="Mjukvaror"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Rapporter"; 
$LANG['Menu'][11]="Alternativ"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Statistik"; 
$LANG['Menu'][14]="Användare"; 
$LANG['Menu'][15]="Administration"; 
$LANG['Menu'][16]="Kringutrustning"; 
$LANG['Menu'][17]="Reservationer"; 
$LANG['Menu'][18]="Verktyg"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Patroner/Toners"; 
$LANG['Menu'][22]="Kontakter"; 
$LANG['Menu'][23]="Leverantörer"; 
$LANG['Menu'][24]="Finansiell information"; 
$LANG['Menu'][25]="Avtal"; 
$LANG['Menu'][26]="Information"; 
$LANG['Menu'][27]="Dokument"; 
$LANG['Menu'][28]="Status"; 
$LANG['Menu'][29]="Planering"; 
$LANG['Menu'][30]="Loggar"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Förbrukningsvaror"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefonienheter"; 
$LANG['Menu'][35]="Profiler"; 
$LANG['Menu'][36]="Grupper"; 
$LANG['Menu'][37]="Enheter"; 
$LANG['Menu'][38]="Inventarier"; 
$LANG['Menu'][39]="Mottagare"; 
$LANG['Menu'][40]="Bokmärken"; 
$LANG['Menu'][41]="Rights"; 

$LANG['monitors'][14]="Mikrofon"; 
$LANG['monitors'][15]="Högtalare"; 
$LANG['monitors'][18]="Flaggor"; 
$LANG['monitors'][19]="D-Sub"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Storlek"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivå"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Nätverksport"; 
$LANG['networking'][13]="nätverksportar funna"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Ansluten till"; 
$LANG['networking'][19]="Ny nätverksport"; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="på"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="Porten"; 
$LANG['networking'][46]="Nya nätverksportar"; 
$LANG['networking'][47]="Från"; 
$LANG['networking'][48]="Till"; 
$LANG['networking'][51]="Anslutningspunkt"; 
$LANG['networking'][55]="Associera ett VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Välj en MAC-adress ur listan eller skriv in den här nere"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Mask"; 
$LANG['networking'][61]="Subnät"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Importalternativ"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
$LANG['ocsconfig'][10]="Global import"; 
$LANG['ocsconfig'][11]="Ingen import"; 
$LANG['ocsconfig'][12]="Unit import"; 
$LANG['ocsconfig'][13]="Unit import: everything is imported 'as-is'"; 
$LANG['ocsconfig'][14]="Global import: everything is imported but the material is globally managed (without double blooms)"; 
$LANG['ocsconfig'][15]="Ingen import av dessa element"; 
$LANG['ocsconfig'][16]="Standard status"; 
$LANG['ocsconfig'][17]="Limit the import to the following tags (separator $, nothing for all)"; 
$LANG['ocsconfig'][18]="Kontrollera att duplikat hanteras oav OCSNG"; 
$LANG['ocsconfig'][19]="Unit import on serial number"; 
$LANG['ocsconfig'][27]="Allmän information"; 
$LANG['ocsconfig'][36]="Modem"; 
$LANG['ocsconfig'][37]="Portar"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Registret"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Behavior when disconnecting"; 
$LANG['ocsconfig'][49]="Papperskorgen"; 
$LANG['ocsconfig'][50]="Deletion"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="tom"; 
$LANG['ocsconfig'][57]="lika med"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Synkronisera datorer som redan är importerade"; 
$LANG['ocsng'][2]="Importera nya datorer"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Länka nya OCS-datorer med existerande GLPI-datorer"; 
$LANG['ocsng'][5]="Importera nya datorer"; 
$LANG['ocsng'][6]="Automatisk uppdatering"; 
$LANG['ocsng'][7]="Importerat från OCSNG"; 
$LANG['ocsng'][8]="Import lyckades"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Uppdatera datorer"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Importera datum till GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Inget fält låst"; 
$LANG['ocsng'][16]="Låsta fält"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Varning! Importerad data skriver över existerande data. (Kontrollera konfigurationen)"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Forcera synkronisering"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Locked monitor(s)"; 
$LANG['ocsng'][32]="Locked device(s)"; 
$LANG['ocsng'][34]="Låst(a) skrivare"; 
$LANG['ocsng'][36]="Destinationsenhet"; 
$LANG['ocsng'][37]="Aktivera förhandsgranskningen"; 
$LANG['ocsng'][38]="Avaktivera förhandsgranskningen"; 
$LANG['ocsng'][40]="Match the rule ?"; 
$LANG['ocsng'][41]="Manuell import"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Låsta IP"; 
$LANG['ocsng'][52]="Låsta programvaror"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Volymen/erna är låst/a"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="till"; 
$LANG['pager'][2]="från"; 
$LANG['pager'][3]="av"; 
$LANG['pager'][4]="Visa"; 
$LANG['pager'][5]="objekt"; 

$LANG['peripherals'][18]="Fabrikat"; 
$LANG['peripherals'][31]="Global hantering"; 
$LANG['peripherals'][32]="Unit management"; 
$LANG['peripherals'][33]="Management Type"; 

$LANG['phones'][18]="Fabrikat"; 
$LANG['phones'][36]="Nätaggregat"; 
$LANG['phones'][38]="Headset"; 
$LANG['phones'][39]="Högtalare"; 
$LANG['phones'][40]="Antal linjer"; 

$LANG['planning'][0]="Den tekniskt ansvariga har redan uppgifter inplanerade för denna tidpunkt"; 
$LANG['planning'][1]="Felaktig tidsangivelse, startdatum > slutdatum"; 
$LANG['planning'][5]="Dag"; 
$LANG['planning'][6]="Vecka"; 
$LANG['planning'][8]="Ärendeuppföljning"; 
$LANG['planning'][9]="Av"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="Webcal:// synkronisering"; 
$LANG['planning'][14]="Månad"; 
$LANG['planning'][15]="Din planering"; 
$LANG['planning'][16]="Information"; 
$LANG['planning'][17]="Att göra"; 
$LANG['planning'][18]="Klart"; 

$LANG['plugins'][0]="Pluginlista"; 
$LANG['plugins'][2]="Installerad/inte konfigurerad"; 
$LANG['plugins'][3]="Installerad/inte aktiverad"; 
$LANG['plugins'][4]="Fel/att rensa"; 
$LANG['plugins'][5]="Icke existerande funktion(er)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Seriellt gränssnitt"; 
$LANG['printers'][15]="Parallellt gränssnitt"; 
$LANG['printers'][18]="Portar"; 
$LANG['printers'][27]="USB port"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Startvärde för sidräknare"; 
$LANG['printers'][31]="Utskrivna sidor"; 

$LANG['profiles'][0]="Global rättighet"; 
$LANG['profiles'][1]="Enhetsbehörighet"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Skapa ärende"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Visa alla ärenden"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Läs"; 
$LANG['profiles'][11]="Skriv"; 
$LANG['profiles'][12]="Ingen access"; 
$LANG['profiles'][13]="Standard profil"; 
$LANG['profiles'][14]="Radera ärende"; 
$LANG['profiles'][15]="Lägg till uppföljningar för alla ärenden"; 
$LANG['profiles'][16]="Äga ärenden"; 
$LANG['profiles'][17]="Överta ärenden"; 
$LANG['profiles'][18]="Uppdatera ärenden"; 
$LANG['profiles'][19]="Delegera ärenden"; 
$LANG['profiles'][20]="Visa egen planering"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Reservationsadministrering"; 
$LANG['profiles'][24]="Uppdatera lösenord"; 
$LANG['profiles'][26]="Visa ärenden för mina grupper"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Rekursiv"; 
$LANG['profiles'][29]="Dynamisk"; 
$LANG['profiles'][30]="Visa OCSNG-information"; 
$LANG['profiles'][31]="Synkronisera OCSNG manuellt"; 
$LANG['profiles'][32]="See assigned tickets (personnal + group associated)"; 
$LANG['profiles'][33]="Hittar ingen användare"; 
$LANG['profiles'][34]="Caption"; 
$LANG['profiles'][35]="Uppdatera alla uppföljningar"; 
$LANG['profiles'][36]="Visa schema för personer i mina grupper"; 
$LANG['profiles'][37]="Förvald enhet"; 
$LANG['profiles'][38]="Synlighet"; 
$LANG['profiles'][39]="Tilldelning"; 
$LANG['profiles'][40]="Uppdatera"; 
$LANG['profiles'][41]="Creation"; 
$LANG['profiles'][42]="Association"; 
$LANG['profiles'][43]="Metod för att validera och synkronisera användare"; 
$LANG['profiles'][44]="Ändra prioritet"; 
$LANG['profiles'][45]="Lägg till en uppgift till alla ärenden"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Lägger till användare från extern källa"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Hive"; 
$LANG['registry'][2]="Path"; 
$LANG['registry'][3]="Nyckel/värde"; 
$LANG['registry'][4]="Registernycklar hittade"; 
$LANG['registry'][5]="Ingen nyckel hittades i registret"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Personliga anteckningar"; 
$LANG['reminder'][1]="Publika anteckningar"; 
$LANG['reminder'][6]="Ny anteckning"; 
$LANG['reminder'][9]="Text"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Utan titel"; 
$LANG['reminder'][16]="Globala anteckningar"; 

$LANG['reports'][0]="Välj rapport att generera"; 
$LANG['reports'][4]="Rapport för hårdvara under avtal"; 
$LANG['reports'][11]="Hårdvara under avtal"; 
$LANG['reports'][12]="Objektstyper"; 
$LANG['reports'][13]="Årtal"; 
$LANG['reports'][15]="Visa rapport"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Standardrapport"; 
$LANG['reports'][27]="Avtalsrapport"; 
$LANG['reports'][28]="Årsrapport"; 
$LANG['reports'][33]="Nätverksrapport"; 
$LANG['reports'][36]="Anslutna objekt"; 
$LANG['reports'][37]="Avlämningspunkter"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Plats"; 
$LANG['reports'][41]="Efter hårdvara"; 
$LANG['reports'][42]="Avlämningspunkt"; 
$LANG['reports'][46]="hårdvaruportar"; 
$LANG['reports'][47]="Nätverksport (anslutet objekt)"; 
$LANG['reports'][49]="Nätverksrapport hårdvara"; 
$LANG['reports'][51]="Nätverksrapport avlämningspunkter"; 
$LANG['reports'][52]="Switch"; 
$LANG['reports'][54]="Nätverksrapport platser"; 
$LANG['reports'][57]="Materiallista"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Startdatum"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Finansiell information hårdvara"; 
$LANG['reports'][63]="Finansiell information övrigt"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Reserverbara objekt"; 
$LANG['reservation'][2]="Device temporarily unavailable"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Reservera"; 
$LANG['reservation'][9]="Reservera objekt"; 
$LANG['reservation'][16]="Till"; 
$LANG['reservation'][17]="Från"; 
$LANG['reservation'][18]="Objektet är redan reserverat på den avsedda tidpunkten"; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Modifiera kommentar"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Rehearsal"; 
$LANG['reservation'][28]="Per vecka"; 
$LANG['reservation'][29]="Per dag"; 
$LANG['reservation'][30]="gånger"; 
$LANG['reservation'][31]="Av"; 
$LANG['reservation'][35]="Pågående och planerade reservationer"; 
$LANG['reservation'][36]="Föregående reservationer"; 
$LANG['reservation'][37]="Inga reservationer"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="Denna åtgärd kommer radera alla pågående reservationer!"; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="är"; 
$LANG['rulesengine'][1]="är inte"; 
$LANG['rulesengine'][2]="innehåller"; 
$LANG['rulesengine'][3]="innehåller inte"; 
$LANG['rulesengine'][4]="som börjar med"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Villkor"; 
$LANG['rulesengine'][7]="Åtgärder"; 
$LANG['rulesengine'][8]="Regelhantering"; 
$LANG['rulesengine'][9]="Logisk operator"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Åtgärdstyp"; 
$LANG['rulesengine'][12]="Fält"; 
$LANG['rulesengine'][13]="Värde"; 
$LANG['rulesengine'][14]="Villkor"; 
$LANG['rulesengine'][15]="Orsak"; 
$LANG['rulesengine'][16]="Villkor"; 
$LANG['rulesengine'][17]="Regler"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Regler för enhets- och rättighetstilldelning"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Tilldela"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Regeltyp"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="Lista regler"; 
$LANG['rulesengine'][30]="Åtgärd"; 
$LANG['rulesengine'][33]="Dropdown dictionary"; 
$LANG['rulesengine'][35]="Software dictionary"; 
$LANG['rulesengine'][36]="Manufacturer dictionary"; 
$LANG['rulesengine'][37]="Rules for assigning a category to software"; 
$LANG['rulesengine'][38]="Recalculate"; 
$LANG['rulesengine'][40]="kategorin"; 
$LANG['rulesengine'][41]="Validation"; 
$LANG['rulesengine'][42]="OCH"; 
$LANG['rulesengine'][43]="ELLER"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Tilldela IP adress"; 
$LANG['rulesengine'][47]="Tilldela: utrustningsnamn + domän"; 
$LANG['rulesengine'][48]="Tilldela utrustning"; 
$LANG['rulesengine'][49]="Tilldela MAC-adress"; 
$LANG['rulesengine'][50]="Datormodell-lexikon"; 
$LANG['rulesengine'][51]="Monitor model dictionary"; 
$LANG['rulesengine'][52]="Phone model dictionary"; 
$LANG['rulesengine'][53]="Peripheral model dictionary"; 
$LANG['rulesengine'][54]="Printer model dictionary"; 
$LANG['rulesengine'][55]="Networking model dictionary"; 
$LANG['rulesengine'][56]="Modeller"; 
$LANG['rulesengine'][60]="Computer type dictionary"; 
$LANG['rulesengine'][61]="Monitor type dictionary"; 
$LANG['rulesengine'][62]="Phone type dictionary"; 
$LANG['rulesengine'][63]="Peripheral type dictionary"; 
$LANG['rulesengine'][64]="Printer type dictionary"; 
$LANG['rulesengine'][65]="Networking device type dictionary"; 
$LANG['rulesengine'][66]="Typer"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Service Pack dictionary"; 
$LANG['rulesengine'][69]="OS versions dictionary"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Rename based on dictionary"; 
$LANG['rulesengine'][77]="Dictionaries"; 
$LANG['rulesengine'][78]="Version"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Global dictionary"; 
$LANG['rulesengine'][81]="Regelresultat"; 
$LANG['rulesengine'][82]="Result details"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Testa regelverket"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Software deleted by GLPI dictionary"; 
$LANG['rulesengine'][90]="Arbete pågår..."; 
$LANG['rulesengine'][91]="Arbetet avslutat."; 
$LANG['rulesengine'][92]="Warning before running rename based on the dictionary"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Manufacturer choice"; 
$LANG['rulesengine'][96]="Rename based on the manufacturer(s)dictionary<br> ( ----- = All)"; 
$LANG['rulesengine'][97]="No element to be tested"; 
$LANG['rulesengine'][100]="Cache-information"; 
$LANG['rulesengine'][102]="Regelnamn"; 
$LANG['rulesengine'][103]="Objekt i cachen"; 
$LANG['rulesengine'][104]="Ursprungsvärde"; 
$LANG['rulesengine'][105]="Ändrat värde"; 
$LANG['rulesengine'][106]="Oförändrad"; 
$LANG['rulesengine'][107]="Inaktiv"; 
$LANG['rulesengine'][108]="original"; 
$LANG['rulesengine'][110]="Rättighetstilldelning"; 
$LANG['rulesengine'][111]="Enhetstilldelning"; 
$LANG['rulesengine'][112]="Tilldelning av enheter och rättigheter"; 
$LANG['rulesengine'][120]="The engine stops on the first checked rule."; 
$LANG['rulesengine'][121]="The engine treats all the rules."; 
$LANG['rulesengine'][122]="The engine passes the result of a rule to the following ones."; 
$LANG['rulesengine'][130]="Enhet från LDAP"; 
$LANG['rulesengine'][131]="Entity from TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Lägg till Villkor"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Sök"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="innehåller"; 
$LANG['search'][4]="sorterat enligt"; 
$LANG['search'][8]="Startdatum"; 
$LANG['search'][9]="Slutdatum"; 
$LANG['search'][10]="i"; 
$LANG['search'][11]="Synliga data"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Inga objekt funna"; 
$LANG['search'][16]="Åtminstonde"; 
$LANG['search'][17]="Lägg till ett sökvillkor"; 
$LANG['search'][18]="Radera ett sökvillkor"; 
$LANG['search'][19]="Lägg till ett globalt sökvillkor"; 
$LANG['search'][20]="Radera ett globalt sökvillkor"; 

$LANG['setup'][0]="Menyval"; 
$LANG['setup'][2]="Ny GPLI användare"; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Dator definitioner"; 
$LANG['setup'][5]="Operativsystem definitioner"; 
$LANG['setup'][6]="Personalization"; 
$LANG['setup'][9]="Nätverksinterface"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Konto"; 
$LANG['setup'][19]="Lösenord"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Followed private for default"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Välj språk"; 
$LANG['setup'][42]="Nätverkstyper"; 
$LANG['setup'][43]="Skrivare definitioner"; 
$LANG['setup'][44]="Bildskärmar definitioner"; 
$LANG['setup'][45]="Chassi definitioner"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Välj kategori att konfigurera"; 
$LANG['setup'][63]="Varning: Du är på väg att ta bort en rubrik som används för minst något objekt"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Du kan också byta alla händelse under denna rubrik mot en annan:"; 
$LANG['setup'][67]="Extern autenticering"; 
$LANG['setup'][69]="Devices types"; 
$LANG['setup'][70]="Allmänna inställningar"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Anslutningspunkt"; 
$LANG['setup'][74]="Du kan ej radera denna plats då den har döttrar under sig"; 
$LANG['setup'][75]="som dotter till"; 
$LANG['setup'][79]="Ärendekategorier"; 
$LANG['setup'][80]="Tredjepartstyp"; 
$LANG['setup'][81]="Dokumentrubriker"; 
$LANG['setup'][82]="Kontakt definitioner"; 
$LANG['setup'][83]="Objektstatus definitioner"; 
$LANG['setup'][84]="Patron/toner typ"; 
$LANG['setup'][85]="Avtalstyp"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Nätverk"; 
$LANG['setup'][89]="Domän"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="Datormodeller"; 
$LANG['setup'][92]="Förbrukningsvarutyp"; 
$LANG['setup'][93]="Interface för hårddisk"; 
$LANG['setup'][94]="Monitors Models"; 
$LANG['setup'][95]="Networking Models"; 
$LANG['setup'][96]="Skrivarmodeller"; 
$LANG['setup'][97]="Peripherals Models"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Loggningsnivå"; 
$LANG['setup'][103]="1 - Kritiska (endast inloggningsfel)"; 
$LANG['setup'][104]="2 - Allvarliga händelser"; 
$LANG['setup'][105]="3 - Viktiga (lyckade inloggningar)"; 
$LANG['setup'][106]="4 - Information"; 
$LANG['setup'][107]="5 - Total (allt)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Visa nya ärenden vid inloggning"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Standardspråk"; 
$LANG['setup'][114]="Prioritetsfärger"; 
$LANG['setup'][115]="Standardnivå för patron/toner och förbrukningsvaror"; 
$LANG['setup'][116]="Delegera automatiskt ärende till tekniskt ansvarig för objektet"; 
$LANG['setup'][117]="Tillåt anonyma tillträde till FAQn"; 
$LANG['setup'][118]="Text på autenticeringssida"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Lägg automatiskt till ny användare från extern autenticeringskälla"; 
$LANG['setup'][125]="...från en extern källa"; 
$LANG['setup'][126]="Lägg automatiskt till ny användare från extern källa"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Datumformat"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Aktivera OSNNG läge"; 
$LANG['setup'][134]="OCSNG läge"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Översättning"; 
$LANG['setup'][137]="Felsökning"; 
$LANG['setup'][138]="GPLI läge"; 
$LANG['setup'][139]="Gemensam"; 
$LANG['setup'][140]="Typer"; 
$LANG['setup'][145]="OS"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Step for the hours"; 
$LANG['setup'][149]="Antal decimaler i mängdangivelser"; 
$LANG['setup'][150]="Nummerformat"; 
$LANG['setup'][154]="BasDN"; 
$LANG['setup'][155]="RootDN"; 
$LANG['setup'][156]="Pass (for non-anonymous binds)"; 
$LANG['setup'][157]="LDAP tillägget i PHP är ej installerad"; 
$LANG['setup'][158]="Kan ej använda LDAP som extern källa för förbindelsen"; 
$LANG['setup'][159]="Anslutningsfilter"; 
$LANG['setup'][162]="IMAP/POP konfiguration"; 
$LANG['setup'][164]="IMAP/POP värdnamn (användares e-post adress är konto@värdnamn)"; 
$LANG['setup'][165]="PHP är ej kompilerat med IMAP funktioner på detta system"; 
$LANG['setup'][166]="Kan ej använda IMAP/POP som extern källa för förbindelsen"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Förbindelsealternativ"; 
$LANG['setup'][169]="Mail folder (optional, often INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Port (valfri)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="CAS värd"; 
$LANG['setup'][175]="CAS port"; 
$LANG['setup'][176]="Root directory (optional)"; 
$LANG['setup'][177]="CAS konfiguration"; 
$LANG['setup'][178]="CURL eller DOMXML tillägget i PHP tolken är ej installerat"; 
$LANG['setup'][179]="Det går ej att använda CAS som extern källa för autenticering"; 
$LANG['setup'][180]="Använd TLS"; 
$LANG['setup'][181]="ldap_start_tls saknas"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Tidzon"; 
$LANG['setup'][190]="x509 certifikat"; 
$LANG['setup'][191]="e-postattribut för x509"; 
$LANG['setup'][192]="Aktiverad"; 
$LANG['setup'][193]="Field holding the login in the _SERVER array"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Behåll status"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Kopiera status för dator"; 
$LANG['setup'][198]="Ange status"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="E-post till administratör"; 
$LANG['setup'][204]="E-post signatur"; 
$LANG['setup'][205]="Sändning av e-post till administratör lyckades"; 
$LANG['setup'][206]="Sändning av e-post till administratör misslyckades"; 
$LANG['setup'][207]="Administratörens 'reply-to' i e-post"; 
$LANG['setup'][217]="PHPs e-post funktion är okänd eller ej aktiverad på detta system"; 
$LANG['setup'][218]="Användning av SMTP krävs"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Tillåtna klockslag för planering"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Inloggningsfält"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Använd en SMTP server för att sända e-post"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP konto"; 
$LANG['setup'][235]="SMTP lösenord"; 
$LANG['setup'][236]="F.d tekninskt ansvarig för detta ärende"; 
$LANG['setup'][237]="Administratör"; 
$LANG['setup'][239]="Tekniskt ansvarig för detta ärende"; 
$LANG['setup'][240]="Aviseringsinställningar"; 
$LANG['setup'][241]="Ingen personlig vy konfigurerad, vill du skapa en?"; 
$LANG['setup'][242]="Alarminställningar"; 
$LANG['setup'][243]="Alarm för förbrukningsvaror"; 
$LANG['setup'][244]="Alarm för patroner/toners"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Larm för avtal"; 
$LANG['setup'][247]="Alarm för finansiell information"; 
$LANG['setup'][248]="Grupp som äger ärendet"; 
$LANG['setup'][249]="Requester group"; 
$LANG['setup'][250]="Display search results by default"; 
$LANG['setup'][252]="Välj standardobjekt att visa"; 
$LANG['setup'][253]="Filter för att söka i grupper"; 
$LANG['setup'][254]="Söktyp"; 
$LANG['setup'][255]="Group attribute containing its users"; 
$LANG['setup'][256]="I användare"; 
$LANG['setup'][257]="I grupper"; 
$LANG['setup'][258]="Användare och Grupper"; 
$LANG['setup'][259]="Tillhör grupper"; 
$LANG['setup'][260]="User attribute containing its groups"; 
$LANG['setup'][261]="Grupp DN"; 
$LANG['setup'][262]="Använd DN i sökningen"; 
$LANG['setup'][263]="Sökfilter för användare"; 
$LANG['setup'][264]="Larm för utgångna licenser"; 
$LANG['setup'][271]="Restrict monitor management"; 
$LANG['setup'][272]="Restrict device management"; 
$LANG['setup'][273]="Begränsa telefonhantering"; 
$LANG['setup'][274]="for manual add"; 
$LANG['setup'][275]="Begränsa skrivarhantering"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Kopiera"; 
$LANG['setup'][284]="Rensa"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Kontrollera om ny version finns tillgänglig"; 
$LANG['setup'][301]="Ny version är tillgänglig"; 
$LANG['setup'][302]="Du hittar det på siten glpi-project.org"; 
$LANG['setup'][303]="Du har den senaste tillgängliga versionen"; 
$LANG['setup'][304]="Uppgraderingskontroll misslyckades, kontrollera proxyinställningar"; 
$LANG['setup'][305]="Varje dag"; 
$LANG['setup'][306]="Uppgraderingsinställningar"; 
$LANG['setup'][307]="Aldrig"; 
$LANG['setup'][308]="Varje vecka"; 
$LANG['setup'][309]="Varje månad"; 
$LANG['setup'][310]="Impossible to connect to site."; 
$LANG['setup'][311]="Anslutning till Proxy servern misslyckades"; 
$LANG['setup'][312]="No data available on the web site"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Link with items for the creation of tickets"; 
$LANG['setup'][351]="Alla objekt"; 
$LANG['setup'][352]="Linkable items to a ticket"; 
$LANG['setup'][360]="Automatiska fält (markerade med *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Default heading when adding a document to a ticket"; 
$LANG['setup'][503]="Telefonmodeller"; 
$LANG['setup'][504]="Telefontyper"; 
$LANG['setup'][505]="Nätadaptertyp för telefoner"; 
$LANG['setup'][601]="LDAP värde"; 
$LANG['setup'][602]="Anslutning till OCSNG-databas"; 
$LANG['setup'][603]="Ny användare"; 
$LANG['setup'][604]="Koppla till en grupp"; 
$LANG['setup'][606]="Kunde inte skapa. Användaren finns redan."; 
$LANG['setup'][607]="Koppla till en profil"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Obligatorisk ärendetitel"; 
$LANG['setup'][611]="Obligatorisk ärendebeskrivning"; 
$LANG['setup'][612]="Obligatorisk ärendekategori"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Länk"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Representativa attribut för enhet"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="Allmän"; 
$LANG['setup'][704]="Notifications"; 
$LANG['setup'][707]="Varningar på bokning"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Mysql replicate"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Databas"; 
$LANG['setup'][803]="Skillnad mellan master och slave"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Slavdatabasen är ej i synk!"; 
$LANG['setup'][809]="MySQL replica: read only"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Inköpt version"; 
$LANG['software'][2]="Använd version"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Obegränsad"; 
$LANG['software'][5]="Versioner"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Lägg till en version"; 
$LANG['software'][8]="Lägg till en licens"; 
$LANG['software'][11]="Licenser"; 
$LANG['software'][17]="Installerad mjukvara"; 
$LANG['software'][19]="Installationer"; 
$LANG['software'][20]="Återstående"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Uppdatera"; 
$LANG['software'][30]="Licenstyper"; 
$LANG['software'][32]="Expiration"; 
$LANG['software'][44]="Installera programvara"; 
$LANG['software'][45]="Avinstallera programvara"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Sammanfogar"; 
$LANG['software'][48]="Sammanfoga"; 
$LANG['software'][49]="Software deleted after merging"; 
$LANG['software'][50]="Tilldelat till datorn"; 
$LANG['software'][51]="The number must be 1 to be able to affect"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Programvarukategori"; 

$LANG['state'][0]="Status"; 
$LANG['state'][6]="Objekttyp"; 
$LANG['state'][7]="Inga objekt funna"; 
$LANG['state'][11]="Sammanfattning"; 

$LANG['stats'][0]="Vilken statistik skall visas"; 
$LANG['stats'][1]="Global"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Ärenden per objekttyp"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Average resolution delay"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Antal lösta ärenden"; 
$LANG['stats'][13]="Antal ärenden"; 
$LANG['stats'][15]="Average resolution delay"; 
$LANG['stats'][16]="Tekniskt ansvarig"; 
$LANG['stats'][20]="Användarnamn"; 
$LANG['stats'][23]="Det finns ingen tillgänglig statistik"; 
$LANG['stats'][25]="Average (real) duration of ticket"; 
$LANG['stats'][27]="Total tidsåtgång för ärendet (verklig)"; 
$LANG['stats'][30]="Average delay to respond to the ticket"; 
$LANG['stats'][31]="Dagar"; 
$LANG['stats'][33]="Minuter"; 
$LANG['stats'][34]="Sekunder"; 
$LANG['stats'][35]="Ärende(n)"; 
$LANG['stats'][44]="Företagsnamn"; 
$LANG['stats'][45]="Ärenden per objekt"; 
$LANG['stats'][47]="Ärenden per användare"; 
$LANG['stats'][48]="(delegerat)"; 
$LANG['stats'][49]="(uppföljningar)"; 

$LANG['title'][5]="Kunskapsdatabas"; 
$LANG['title'][6]="Nätverk"; 
$LANG['title'][9]="Objektstatus"; 
$LANG['title'][10]="Ärendeuppföljning"; 
$LANG['title'][13]="Användarinformation"; 
$LANG['title'][14]="Extern autenticering"; 
$LANG['title'][24]="Supporthantering"; 
$LANG['title'][26]="Allmänt"; 
$LANG['title'][27]="Anslutna objekt"; 
$LANG['title'][28]="Ärenden"; 
$LANG['title'][30]="Komponenter"; 
$LANG['title'][33]="Externa länkar"; 
$LANG['title'][34]="Länkar"; 
$LANG['title'][37]="Anteckningar"; 
$LANG['title'][38]="Historik"; 
$LANG['title'][40]="Publika och personliga anteckningar"; 
$LANG['title'][42]="Massiv ändring"; 
$LANG['title'][43]="Register"; 

$LANG['tracking'][1]="Mina objekt"; 
$LANG['tracking'][2]="Komplett sökning"; 
$LANG['tracking'][3]="Ogiltigt datum. Uppdateringen avbröts."; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="Ingen beskrivning, försök igen"; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Document Ticket"; 
$LANG['tracking'][29]="Antal"; 
$LANG['tracking'][30]="Nya"; 
$LANG['tracking'][31]="Pågående (delegerade)"; 
$LANG['tracking'][32]="Pågående (planerade)"; 
$LANG['tracking'][34]="Direkt"; 
$LANG['tracking'][35]="Skrivet"; 
$LANG['tracking'][37]="Behåll ärenden när hårdvaruobjekt rensas bort"; 
$LANG['tracking'][38]="Ett meddelande skickades till"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Förflyttning"; 
$LANG['transfer'][3]="Om det inte används"; 
$LANG['transfer'][4]="För att tömma listan på objekt som ska flyttas"; 
$LANG['transfer'][5]="Du kan fortsätta att lägga till objekt som ska flyttas, eller direkt flytta listade objekt"; 
$LANG['transfer'][6]="Gör gärna en säkerhetskopiering innan du flyttar objekten"; 
$LANG['transfer'][7]="Objekt att flyttas"; 
$LANG['transfer'][8]="Förflyttningsmetod"; 

$LANG['update'][88]="Databasen är inte kompatibel med denna GLPI versionen. En uppdatering är nödvändig"; 
$LANG['update'][89]="Du försöker använda GLPI med en databas som är skapad för en högre version än din. Installera versionen avsedd för din databas."; 
$LANG['update'][90]="Databasuppdateringen misslyckades"; 
$LANG['update'][91]="Varning!"; 
$LANG['update'][92]="Uppdatering kommer ske av databasen:"; 
$LANG['update'][93]="Anslutning till databasen lyckades"; 
$LANG['update'][94]="Dabasuppdateringen lyckades"; 
$LANG['update'][95]="Anslutningen till databasen misslyckades. Kontrollera anslutningsupgifterna i filen config_db.php"; 
$LANG['update'][96]="Administratörer har nu fått fulla rättigheter."; 
$LANG['update'][105]="Det går ej att uppdatera!"; 
$LANG['update'][106]="Återvänd till GLPI"; 
$LANG['update'][107]="Systemet måste nu uppdatera databasens innehåll"; 
$LANG['update'][130]="Platsuppdatering"; 
$LANG['update'][131]="Den nya strukturen är hirarkisk"; 
$LANG['update'][132]="Om du använde en teckenavgränsare, kan du ange den för att automatisera skapandet av den nya hierarkin."; 
$LANG['update'][133]="You can also specify a root location which will include all the generated locations."; 
$LANG['update'][134]="Avgränsningstecken"; 
$LANG['update'][135]="Root location"; 
$LANG['update'][136]="This is the new hierarchy. If it's complete approve it."; 
$LANG['update'][137]="Ny hirarki"; 
$LANG['update'][138]="Verkliga platser"; 
$LANG['update'][139]="Tabelloptimering"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Titel"; 
$LANG['users'][2]="Kategori"; 

$LANG['validation'][0]="Approval"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Approval date"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Approval comment"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Korrekt"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Approval request"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Tickets awaiting approval"; 
?>